@@ -119,13 +119,13 @@ class LoginRequest(DSRequest):
                             ) for item in Jasper_reports_users.objects.filter(user=user)]
                         )
                         request.session['ws_channel'] = ws_channel
-                        request.session['ws_port'] = settings.WS_PORT
-                        request.session['host'] = settings.WS_HOST
-                        request.session['username'] = user.username
-                        request.session['fio'] = user.get_short_name
-                        request.session['user_id'] = user.id
-                        request.session['is_admin'] = user.is_admin
-                        request.session['is_develop'] = user.is_develop
+                        # request.session['ws_port'] = settings.WS_PORT
+                        # request.session['host'] = settings.WS_HOST
+                        # request.session['username'] = user.username
+                        # request.session['fio'] = user.get_short_name
+                        # request.session['user_id'] = user.id
+                        # request.session['is_admin'] = user.is_admin
+                        # request.session['is_develop'] = user.is_develop
                         user.last_login = datetime.now()
                         user.save()
 
