@@ -4,7 +4,7 @@ import uuid
 from typing import Text
 
 from django.conf import settings
-from django.db import connection
+from django.db import connection, OperationalError
 
 from isc_common.common import blinkString
 
@@ -156,7 +156,7 @@ def refresh_mat_view(mat_view_name, progressStack=None):
     if not exists_base_object(mat_view_name):
         return
 
-    sql_txt = f'REFRESH MATERIALIZED VIEW {mat_view_name};'
+    sql_txt = f'REFRESH MATERIALIZED VIEW CONCURRENTLY {mat_view_name};'
     key = f'refresh_mat_view_{mat_view_name}'
     settings.LOCKS.acquire(key)
     try:
@@ -168,6 +168,29 @@ def refresh_mat_view(mat_view_name, progressStack=None):
         if progressStack != None:
             progressStack.close()
         return True
+
+    except OperationalError:
+        sql_txt = f'REFRESH MATERIALIZED VIEW  {mat_view_name};'
+        key = f'refresh_mat_view_{mat_view_name}'
+        settings.LOCKS.acquire(key)
+        try:
+            with connection.cursor() as cursor:
+                if progressStack != None:
+                    progressStack.setContentsLabel(blinkString(f'Обновление материализованного преставления {mat_view_name}', bold=True))
+                cursor.execute(sql_txt)
+            settings.LOCKS.release(key)
+            if progressStack != None:
+                progressStack.close()
+            return True
+
+        except Exception as ex:
+            exc_info = sys.exc_info()
+            logger.error(msg=ex, exc_info=exc_info)
+            settings.LOCKS.release(key)
+            if progressStack != None:
+                progressStack.close()
+            return False
+
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
