@@ -1,13 +1,14 @@
 import datetime
 
 
-def DateToStr(date, mask='%d.%m.%Y', hours=0):
+def DateToStr(date, mask='%d.%m.%Y', hours=3):
     if date == None:
         return None
     if isinstance(date, str):
         date = StrToDate(date)
     return datetime.datetime.strftime(date + datetime.timedelta(hours=hours), mask)
 
+
 def DateTimeToStr(date, mask='%d.%m.%Y %H:%M:%S', hours=0):
     if date == None:
         return None
@@ -15,6 +16,7 @@ def DateTimeToStr(date, mask='%d.%m.%Y %H:%M:%S', hours=0):
         date = StrToDate(date)
     return datetime.datetime.strftime(date + datetime.timedelta(hours=hours), mask)
 
+
 def manth_name(month):
     if month == '01':
         return 'Январь'
@@ -79,11 +81,15 @@ def manth_name(month):
 # %X	Locale’s appropriate time representation.	07:06:05
 # %%	A literal '%' character.	%
 
-def StrToDate(value_str, mask='%Y-%m-%dT%H:%M:%S'):
+def StrToDate(value_str, mask='%Y-%m-%dT%H:%M:%S', hours=0):
     if value_str == None:
         return None
+
+    if isinstance(value_str, datetime.date):
+        return value_str
+
     if len(value_str.split('.')) == 2:
         value_str = value_str.split('.')[0]
     res = datetime.datetime.strptime(value_str, mask)
-    return res
-    # return res + datetime.timedelta(hours=3)
+    # return res
+    return res + datetime.timedelta(hours=hours)
