@@ -28,6 +28,7 @@ class BodyWrapper(Wrapper):
     login = None
     json = None
     httpHeaders = None
+    transaction = None
 
 
 class Body:
@@ -36,6 +37,16 @@ class Body:
             raise Exception('body must by dict')
 
         self.body = BodyWrapper(**body)
+        if self.body.transaction != None:
+            operations = self.body.transaction.get('operations')
+            if isinstance(operations, list):
+                for operation in operations:
+                    data = operation.get('data')
+                    httpHeaders = data.get('httpHeaders')
+                    if isinstance(httpHeaders, dict):
+                        self.body.httpHeaders = httpHeaders
+                        break
+
         if self.body.httpHeaders != None:
             self.body.httpHeaders = Wrapper(**self.body.httpHeaders)
         elif self.body.data != None and self.body.data.get('httpHeaders') != None:
