@@ -518,7 +518,7 @@ class CommonManager(Manager):
     def refresh_mat_view(self, mat_view):
         with connection.cursor() as cursor:
             logger.debug(f'Refreshing: {mat_view}')
-            cursor.execute(f'REFRESH MATERIALIZED VIEW {mat_view};')
+            cursor.execute(f'REFRESH MATERIALIZED VIEW CONCURRENTLY {mat_view};')
             logger.debug(f'Refreshed')
 
     def get_field(self, field_name, model=None):
