@@ -18,6 +18,9 @@ logger = logging.getLogger(__name__)
 class BaseRefQuerySet(AuditQuerySet):
 
     def filter(self, *args, **kwargs):
+        # if self.alive_only:
+        #     setAttr(kwargs, 'deleted_at__isnull', True)
+
         key = [key for key in kwargs.keys() if key == 'full_name']
         if len(key) == 0:
             return super().filter(*args, **kwargs)
@@ -26,9 +29,9 @@ class BaseRefQuerySet(AuditQuerySet):
             if full_name != None:
                 res = self.get_full_name_id(None, full_name[1:])
                 delAttr(kwargs, 'full_name')
-                kwargs.setdefault('pk', res.pk)
+                setAttr(kwargs, 'pk', res.pk)
             else:
-                kwargs.setdefault('pk', 0)
+                setAttr(kwargs, 'pk', 0)
             return super().filter(*args, **kwargs)
 
     def get_full_name_id(self, parent_id, name):
