@@ -32,7 +32,7 @@ class Messages_theme_Manager(CommonTreeGridManager):
     def createFromRequest(self, request):
         from tracker.models.messages_theme_users_access import MessagesThemeUsersAccess
 
-        user_id = request.session._session.get('user_id')
+        user_id = request.user.id
         _request = DSRequest(request=request)
         data = _request.get_data()
         _data = data.copy()
